==> com.liferay.site.cms.site.initializer-1.0.22-sources.jar: com/liferay/site/cms/site/initializer/internal/frontend/data/set/view/table/BulkActionTaskReportCMSTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.site.cms.site.initializer.internal.constants.CMSSiteInitializerFDSNames;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Luca Pellizzon
 */
@Component(
	property = "frontend.data.set.name=" + CMSSiteInitializerFDSNames.BULK_ACTION_TASK_REPORT_SECTION,
	service = FDSView.class
)
public class BulkActionTaskReportCMSTableFDSView extends BaseCMSTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"id", "id",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"actionLink"
			).setSortable(
				true
			)
		).add(
			"actionName", "action-name",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"externalReferenceCode", "external-reference-code",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			addDateFDSTableSchemaField("dateCreated", "create-date")
		).add(
			addDateFDSTableSchemaField("completionDate", "completion-date")
		).add(
			"creator.name", "author-name",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"numberOfItems", "number-of-items",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"executionStatus", "execution-status"
		).build();
	}

	@Override
	public boolean isDefault(String fdsName) {
		return true;
	}

	@Reference
	protected FDSTableSchemaBuilderFactory fdsTableSchemaBuilderFactory;

}

==> com.liferay.site.cms.site.initializer-1.0.23-sources.jar: com/liferay/site/cms/site/initializer/internal/frontend/data/set/view/table/BulkActionTaskReportCMSTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.site.cms.site.initializer.internal.constants.CMSSiteInitializerFDSNames;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Luca Pellizzon
 */
@Component(
	property = "frontend.data.set.name=" + CMSSiteInitializerFDSNames.BULK_ACTION_TASK_REPORT_SECTION,
	service = FDSView.class
)
public class BulkActionTaskReportCMSTableFDSView extends BaseCMSTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"id", "id",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"actionLink"
			).setSortable(
				true
			)
		).add(
			"actionName", "action-name",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"externalReferenceCode", "external-reference-code",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			addDateFDSTableSchemaField("dateCreated", "create-date")
		).add(
			addDateFDSTableSchemaField("completionDate", "completion-date")
		).add(
			"creator.name", "author-name",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"numberOfItems", "number-of-items",
			fdsTableSchemaField -> fdsTableSchemaField.setSortable(true)
		).add(
			"executionStatus", "result",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"result")
		).build();
	}

	@Override
	public boolean isDefault(String fdsName) {
		return true;
	}

	@Reference
	protected FDSTableSchemaBuilderFactory fdsTableSchemaBuilderFactory;

}
